##  Step 5: Get Region Code Details
To integrate Amazon Bedrock with SAP LeanIX, get the region code of the AWS cluster where your agents are configured.
![AWS region selection menu showing region names and codes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio5cf14fb7766e415999de11cd9bc7f258_LowRes.png)
Example Region Codes
